pg_fts package
==============

Submodules
----------

pg_fts.fields module
--------------------

.. automodule:: pg_fts.fields
    :members:

pg_fts.aggregates module
------------------------

.. note::
    
    Deprecated use :mod:`pg_fts.ranks` instead.

pg_fts.ranks module
------------------------

.. automodule:: pg_fts.ranks 
    :members:


pg_fts.introspection module
---------------------------

.. automodule:: pg_fts.introspection
    :members:


pg_fts.migrations module
------------------------

.. automodule:: pg_fts.migrations
    :members:


pg_fts.utils module
-------------------

.. automodule:: pg_fts.utils
    :members:


Module contents
---------------

.. automodule:: pg_fts
    :members:
